<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>QtLocationQML</name>
    <message>
        <source>Plugin property is not set.</source>
        <translation>A propriedade do plugin não foi definida.</translation>
    </message>
    <message>
        <source>Plugin Error (%1): %2</source>
        <translation>Erro no plugin (%1): %2</translation>
    </message>
    <message>
        <source>Plugin Error (%1): Could not instantiate provider</source>
        <translation>Erro no plugin (%1): Não foi possível instanciar o fornecedor</translation>
    </message>
    <message>
        <source>Plugin is not valid</source>
        <translation>O plugin não é válido</translation>
    </message>
    <message>
        <source>Unable to initialize categories</source>
        <translation>Não foi possível inicializar as categorias</translation>
    </message>
    <message>
        <source>Unable to create request</source>
        <translation>Não foi possível criar a requisição</translation>
    </message>
    <message>
        <source>Index &apos;%1&apos; out of range</source>
        <translation>Índice &apos;%1&apos; fora da faixa</translation>
    </message>
    <message>
        <source>Qt Location requires apiKey parameter.
Please register at https://developer.here.com/ to get your personal application credentials.</source>
        <translation>O Qt Location requer o parâmetro apiKey.
Registre-se em https://developer.here.com/ para obter suas credenciais de inscrição.</translation>
    </message>
    <message>
        <source>Saving places is not supported.</source>
        <translation>Salvar lugares não é suportado.</translation>
    </message>
    <message>
        <source>Removing places is not supported.</source>
        <translation>Excluir lugares não é suportado.</translation>
    </message>
    <message>
        <source>Saving categories is not supported.</source>
        <translation>Salvar categorias não é suportado.</translation>
    </message>
    <message>
        <source>Removing categories is not supported.</source>
        <translation>Excluir categorias não é suportado.</translation>
    </message>
    <message>
        <source>Error parsing response.</source>
        <translation>Erro ao analisar a resposta.</translation>
    </message>
    <message>
        <source>Network error.</source>
        <translation>Erro de rede.</translation>
    </message>
    <message>
        <source>Request was canceled.</source>
        <translation>A requisição foi cancelada.</translation>
    </message>
    <message>
        <source>The response from the service was not in a recognizable format.</source>
        <translation>A resposta do servidor não veio em um formato reconhecido.</translation>
    </message>
    <message>
        <source>Qt Location requires app_id and token parameters.
Please register at https://developer.here.com/ to get your personal application credentials.</source>
        <translation>O Qt Location necessita dos parâmetros app_id e token.
Registre-se em https://developer.here.com/ para obter sua credencial de aplicativo pessoal.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeocodeModel</name>
    <message>
        <source>Cannot geocode, plugin not set.</source>
        <translation>Não foi possível geocodificar, plugin não configurado.</translation>
    </message>
    <message>
        <source>Cannot geocode, geocode manager not set.</source>
        <translation>Não foi possível geocodificar, gerenciador de geocodificação não configurado.</translation>
    </message>
    <message>
        <source>Cannot geocode, valid query not set.</source>
        <translation>Não foi possível geocodificar, consulta válida não configurada.</translation>
    </message>
    <message>
        <source>Plugin does not support (reverse) geocoding.</source>
        <translation>O plugin não suporta geocodificação (reversa).</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoRouteModel</name>
    <message>
        <source>Plugin does not support routing.</source>
        <translation>O plugin não suporta roteamento.</translation>
    </message>
    <message>
        <source>Cannot route, plugin not set.</source>
        <translation>Não foi possível rotear, plugin não configurado.</translation>
    </message>
    <message>
        <source>Cannot route, route manager not set.</source>
        <translation>Não foi possível rotear, gerenciador de rotas não configurado.</translation>
    </message>
    <message>
        <source>Cannot route, valid query not set.</source>
        <translation>Não foi possível rotear, consulta válida não configurada.</translation>
    </message>
    <message>
        <source>Not enough waypoints for routing.</source>
        <translation>Poucos pontos para roteamento.</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV5</name>
    <message>
        <source>North</source>
        <extracomment>Translations exist at https://github.com/Project-OSRM/osrm-text-instructions. Always used in &quot;Head %1 [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>norte</translation>
    </message>
    <message>
        <source>East</source>
        <translation>leste</translation>
    </message>
    <message>
        <source>South</source>
        <translation>sul</translation>
    </message>
    <message>
        <source>West</source>
        <translation>oeste</translation>
    </message>
    <message>
        <source>first</source>
        <comment>roundabout exit</comment>
        <extracomment>always used in &quot; and take the %1 exit [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>primeira</translation>
    </message>
    <message>
        <source>second</source>
        <comment>roundabout exit</comment>
        <translation>segunda</translation>
    </message>
    <message>
        <source>third</source>
        <comment>roundabout exit</comment>
        <translation>terceira</translation>
    </message>
    <message>
        <source>fourth</source>
        <comment>roundabout exit</comment>
        <translation>quarta</translation>
    </message>
    <message>
        <source>fifth</source>
        <comment>roundabout exit</comment>
        <translation>quinta</translation>
    </message>
    <message>
        <source>sixth</source>
        <comment>roundabout exit</comment>
        <translation>sexta</translation>
    </message>
    <message>
        <source>seventh</source>
        <comment>roundabout exit</comment>
        <translation>sétima</translation>
    </message>
    <message>
        <source>eighth</source>
        <comment>roundabout exit</comment>
        <translation>oitava</translation>
    </message>
    <message>
        <source>ninth</source>
        <comment>roundabout exit</comment>
        <translation>nona</translation>
    </message>
    <message>
        <source>tenth</source>
        <comment>roundabout exit</comment>
        <translation>décima</translation>
    </message>
    <message>
        <source>eleventh</source>
        <comment>roundabout exit</comment>
        <translation>décima primeira</translation>
    </message>
    <message>
        <source>twelfth</source>
        <comment>roundabout exit</comment>
        <translation>décima segunda</translation>
    </message>
    <message>
        <source>thirteenth</source>
        <comment>roundabout exit</comment>
        <translation>décima terceira</translation>
    </message>
    <message>
        <source>fourteenth</source>
        <comment>roundabout exit</comment>
        <translation>décima quarta</translation>
    </message>
    <message>
        <source>fifteenth</source>
        <comment>roundabout exit</comment>
        <translation>décima quinta</translation>
    </message>
    <message>
        <source>sixteenth</source>
        <comment>roundabout exit</comment>
        <translation>décima sexta</translation>
    </message>
    <message>
        <source>seventeenth</source>
        <comment>roundabout exit</comment>
        <translation>décima sétima</translation>
    </message>
    <message>
        <source>eighteenth</source>
        <comment>roundabout exit</comment>
        <translation>décima oitava</translation>
    </message>
    <message>
        <source>nineteenth</source>
        <comment>roundabout exit</comment>
        <translation>décima nona</translation>
    </message>
    <message>
        <source>twentieth</source>
        <comment>roundabout exit</comment>
        <translation>vigéssima</translation>
    </message>
    <message>
        <source> and take the %1 exit</source>
        <extracomment>Always appended to one of the following strings: - &quot;Enter the roundabout&quot; - &quot;Enter the rotary&quot; - &quot;Enter the rotary &lt;rotaryname&gt;&quot;</extracomment>
        <translation> e pegue a %1 saída</translation>
    </message>
    <message>
        <source> and take the %1 exit onto %2</source>
        <translation> e pegue a %1 saída em %2</translation>
    </message>
    <message>
        <source>You have arrived at your destination, straight ahead</source>
        <translation>Você chegou ao destino, siga em frente</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the left</source>
        <translation>Você chegou ao destino, à esquerda</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the right</source>
        <translation>Você chegou ao destino, à direita</translation>
    </message>
    <message>
        <source>You have arrived at your destination</source>
        <translation>Você chegou ao destino</translation>
    </message>
    <message>
        <source>Continue straight</source>
        <translation>Continue em frente</translation>
    </message>
    <message>
        <source>Continue straight on %1</source>
        <translation>Continue em frente em %1</translation>
    </message>
    <message>
        <source>Continue left</source>
        <translation>Continue à esquerda</translation>
    </message>
    <message>
        <source>Continue left onto %1</source>
        <translation>Continue à esquerda em %1</translation>
    </message>
    <message>
        <source>Continue slightly left</source>
        <translation>Continue ligeiramente à esquerda</translation>
    </message>
    <message>
        <source>Continue slightly left on %1</source>
        <translation>Continue ligeiramente à esquerda em %1</translation>
    </message>
    <message>
        <source>Continue right</source>
        <translation>Continue à direita</translation>
    </message>
    <message>
        <source>Continue right onto %1</source>
        <translation>Continue à direita em %1</translation>
    </message>
    <message>
        <source>Continue slightly right</source>
        <translation>Continue ligeiramente à direita</translation>
    </message>
    <message>
        <source>Continue slightly right on %1</source>
        <translation>Continue ligeiramente à direita em %1</translation>
    </message>
    <message>
        <source>Make a U-turn</source>
        <translation>Faça retorno</translation>
    </message>
    <message>
        <source>Make a U-turn onto %1</source>
        <translation>Faça retorno em %1</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continue</translation>
    </message>
    <message>
        <source>Continue on %1</source>
        <translation>Continue em %1</translation>
    </message>
    <message>
        <source>Head %1</source>
        <extracomment>%1 is &quot;North&quot;, &quot;South&quot;, &quot;East&quot; or &quot;West&quot;</extracomment>
        <translation>Siga para o %1</translation>
    </message>
    <message>
        <source>Head %1 onto %2</source>
        <translation>Siga para o %1 em %2</translation>
    </message>
    <message>
        <source>Depart</source>
        <translation>Siga</translation>
    </message>
    <message>
        <source>Depart onto %1</source>
        <translation>Siga em %1</translation>
    </message>
    <message>
        <source>At the end of the road, turn left</source>
        <translation>No final da rua, vire à esquerda</translation>
    </message>
    <message>
        <source>At the end of the road, turn left onto %1</source>
        <translation>No final da rua, vire à esquerda em %1</translation>
    </message>
    <message>
        <source>At the end of the road, turn right</source>
        <translation>No final da rua, vire à direita</translation>
    </message>
    <message>
        <source>At the end of the road, turn right onto %1</source>
        <translation>No final da rua, vire à direita em %1</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn</source>
        <translation>No final da rua, faça retorno</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn onto %1</source>
        <translation>No final da rua, faça retorno em %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight</source>
        <translation>No final da rua, siga em frente</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight onto %1</source>
        <translation>No final da rua, siga em frente em %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue</source>
        <translation>No final da rua, continue</translation>
    </message>
    <message>
        <source>At the end of the road, continue onto %1</source>
        <translation>No final da rua, continue em %1</translation>
    </message>
    <message>
        <source>Take the ferry</source>
        <translation>Pegue a balsa</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left</source>
        <translation>Na bifurcação, faça uma curva acentuada à esquerda</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left onto %1</source>
        <translation>Na bifurcação, faça uma curva acentuada à esquerda em %1</translation>
    </message>
    <message>
        <source>At the fork, turn left</source>
        <translation>Na bifurcação, vire à esquerda</translation>
    </message>
    <message>
        <source>At the fork, turn left onto %1</source>
        <translation>Na bifurcação, vire à esquerda em %1</translation>
    </message>
    <message>
        <source>At the fork, keep left</source>
        <translation>Na bifurcação, mantenha-se à esquerda</translation>
    </message>
    <message>
        <source>At the fork, keep left onto %1</source>
        <translation>Na bifurcação, mantenha-se à esquerda em %1</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right</source>
        <translation>Na bifurcação, faça uma curva acentuada à direita</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right onto %1</source>
        <translation>Na bifurcação, faça uma curva acentuada à direita em %1</translation>
    </message>
    <message>
        <source>At the fork, turn right</source>
        <translation>Na bifurcação, vire à direita</translation>
    </message>
    <message>
        <source>At the fork, turn right onto %1</source>
        <translation>Na bifurcação, vire à direita em %1</translation>
    </message>
    <message>
        <source>At the fork, keep right</source>
        <translation>Na bifurcação, mantenha-se à direita</translation>
    </message>
    <message>
        <source>At the fork, keep right onto %1</source>
        <translation>Na bifurcação, mantenha-se à direita em %1</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead</source>
        <translation>Na bifurcação, siga em frente</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead onto %1</source>
        <translation>Na bifurcação, siga em frente em %1</translation>
    </message>
    <message>
        <source>At the fork, continue</source>
        <translation>Na bifurcação, continue</translation>
    </message>
    <message>
        <source>At the fork, continue onto %1</source>
        <translation>Na bifurcação, continue em %1</translation>
    </message>
    <message>
        <source>Merge sharply left</source>
        <translation>Junção acentuada à esquerda</translation>
    </message>
    <message>
        <source>Merge sharply left onto %1</source>
        <translation>Junção acentuada à esquerda em %1</translation>
    </message>
    <message>
        <source>Merge left</source>
        <translation>Junção à esquerda</translation>
    </message>
    <message>
        <source>Merge left onto %1</source>
        <translation>Junção à esquerda em %1</translation>
    </message>
    <message>
        <source>Merge slightly left</source>
        <translation>Junção leve à esquerda</translation>
    </message>
    <message>
        <source>Merge slightly left on %1</source>
        <translation>Junção leve à esquerda em %1</translation>
    </message>
    <message>
        <source>Merge sharply right</source>
        <translation>Junção acentuada à direita</translation>
    </message>
    <message>
        <source>Merge sharply right onto %1</source>
        <translation>Junção acentuada à direita em %1</translation>
    </message>
    <message>
        <source>Merge right</source>
        <translation>Junção à direita</translation>
    </message>
    <message>
        <source>Merge right onto %1</source>
        <translation>Junção à direita em %1</translation>
    </message>
    <message>
        <source>Merge slightly right</source>
        <translation>Junção leve à direita</translation>
    </message>
    <message>
        <source>Merge slightly right on %1</source>
        <translation>Junção leve à direita em %1</translation>
    </message>
    <message>
        <source>Merge straight</source>
        <translation>Junção à frente</translation>
    </message>
    <message>
        <source>Merge straight on %1</source>
        <translation>Junção à frente em %1</translation>
    </message>
    <message>
        <source>Merge</source>
        <translation>Junção</translation>
    </message>
    <message>
        <source>Merge onto %1</source>
        <translation>Junção em %1</translation>
    </message>
    <message>
        <source>Take a sharp left</source>
        <translation>Vire na curva acentuada à esquerda</translation>
    </message>
    <message>
        <source>Take a sharp left onto %1</source>
        <translation>Vire na curva acentuada à esquerda em %1</translation>
    </message>
    <message>
        <source>Turn left</source>
        <translation>Vire à esquerda</translation>
    </message>
    <message>
        <source>Turn left onto %1</source>
        <translation>Vire à esquerda em %1</translation>
    </message>
    <message>
        <source>Continue slightly left onto %1</source>
        <translation>Mantenha-se levemente à esquerda em %1</translation>
    </message>
    <message>
        <source>Take a sharp right</source>
        <translation>Vire na curva acentuada à direita</translation>
    </message>
    <message>
        <source>Take a sharp right onto %1</source>
        <translation>Vire na curva acentuada à direita em %1</translation>
    </message>
    <message>
        <source>Turn right</source>
        <translation>Vire à direita</translation>
    </message>
    <message>
        <source>Turn right onto %1</source>
        <translation>Vire à direita em %1</translation>
    </message>
    <message>
        <source>Continue slightly right onto %1</source>
        <translation>Mantenha-se levemente à direita em %1</translation>
    </message>
    <message>
        <source>Continue straight onto %1</source>
        <translation>Mantenha-se em frente em %1</translation>
    </message>
    <message>
        <source>Continue onto %1</source>
        <translation>Mantenha-se em %1</translation>
    </message>
    <message>
        <source>Continue on the left</source>
        <translation>Mantenha-se à esquerda</translation>
    </message>
    <message>
        <source>Continue on the left on %1</source>
        <translation>Mantenha-se à esquerda em %1</translation>
    </message>
    <message>
        <source>Continue on the right</source>
        <translation>Mantenha-se à direita</translation>
    </message>
    <message>
        <source>Continue on the right on %1</source>
        <translation>Mantenha-se à direita em %1</translation>
    </message>
    <message>
        <source>Take the ramp on the left</source>
        <translation>Pegue a rampa à esquerda</translation>
    </message>
    <message>
        <source>Take the ramp on the left onto %1</source>
        <translation>Pegue a rampa à esquerda em %1</translation>
    </message>
    <message>
        <source>Take the ramp on the right</source>
        <translation>Pegue a rampa à direita</translation>
    </message>
    <message>
        <source>Take the ramp on the right onto %1</source>
        <translation>Pegue a rampa à direita em %1</translation>
    </message>
    <message>
        <source>Take the ramp</source>
        <translation>Pegue a rampa</translation>
    </message>
    <message>
        <source>Take the ramp onto %1</source>
        <translation>Pegue a rampa em %1</translation>
    </message>
    <message>
        <source>Get off the bike and push</source>
        <translation>Saia da bicicleta e empurre-a</translation>
    </message>
    <message>
        <source>Get off the bike and push onto %1</source>
        <translation>Saia da bicicleta e empurre-a em %1</translation>
    </message>
    <message>
        <source>Enter the rotary</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Entre na rotatória</translation>
    </message>
    <message>
        <source>Enter the roundabout</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Entre na rotatória</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight</source>
        <translation>Na rotatória, siga em frente</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight on %1</source>
        <translation>Na rotatória, siga em frente em %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn left</source>
        <translation>Na rotatória, vire à esquerda</translation>
    </message>
    <message>
        <source>At the roundabout, turn left onto %1</source>
        <translation>Na rotatória, vire à esquerda em %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn right</source>
        <translation>Na rotatória, vire à direita</translation>
    </message>
    <message>
        <source>At the roundabout, turn right onto %1</source>
        <translation>Na rotatória, vire à direita em %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn around</source>
        <translation>Na rotatória, dê a volta</translation>
    </message>
    <message>
        <source>At the roundabout, turn around onto %1</source>
        <translation>Na rotatória, dê a volta em %1</translation>
    </message>
    <message>
        <source>At the roundabout, continue</source>
        <translation>Na rotatória, continue</translation>
    </message>
    <message>
        <source>At the roundabout, continue onto %1</source>
        <translation>Na rotatória, continue em %1</translation>
    </message>
    <message>
        <source>Take the train</source>
        <translation>Pegue o trem</translation>
    </message>
    <message>
        <source>Take the train [%1]</source>
        <translation>Pegue o trem [%1]</translation>
    </message>
    <message>
        <source>Go straight</source>
        <translation>Siga em frente</translation>
    </message>
    <message>
        <source>Go straight onto %1</source>
        <translation>Siga em frente em %1</translation>
    </message>
    <message>
        <source>Turn slightly left</source>
        <translation>Vire levemente à esquerda</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1</source>
        <translation>Vire levemente à esquerda em %1</translation>
    </message>
    <message>
        <source>Turn slightly right</source>
        <translation>Vire levemente à direita</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1</source>
        <translation>Vire levemente à direita em %1</translation>
    </message>
    <message>
        <source>Turn</source>
        <translation>Vire</translation>
    </message>
    <message>
        <source>Turn onto %1</source>
        <translation>Vire em %1</translation>
    </message>
    <message>
        <source> and continue straight</source>
        <extracomment>This string will be prepended with lane instructions. E.g., &quot;Use the left or the right lane and continue straight&quot;</extracomment>
        <translation> e siga em frente</translation>
    </message>
    <message>
        <source> and continue straight onto %1</source>
        <translation> e siga em frente em %1</translation>
    </message>
    <message>
        <source> and make a sharp left</source>
        <translation> e então vire na curva acentuada à esquerda</translation>
    </message>
    <message>
        <source> and make a sharp left onto %1</source>
        <translation> e então vire na curva acentuada à esquerda em %1</translation>
    </message>
    <message>
        <source> and turn left</source>
        <translation> e vire à esquerda</translation>
    </message>
    <message>
        <source> and turn left onto %1</source>
        <translation> e vire à esquerda em %1</translation>
    </message>
    <message>
        <source> and make a slight left</source>
        <translation> e então vire na curva leve à esquerda</translation>
    </message>
    <message>
        <source> and make a slight left onto %1</source>
        <translation> e então vire na curva leve à esquerda em %1</translation>
    </message>
    <message>
        <source> and make a sharp right</source>
        <translation> e então vire na curva acentuada à direita</translation>
    </message>
    <message>
        <source> and make a sharp right onto %1</source>
        <translation> e então vire na curva acentuada à direita em %1</translation>
    </message>
    <message>
        <source> and turn right</source>
        <translation> e então vire à direita</translation>
    </message>
    <message>
        <source> and turn right onto %1</source>
        <translation> e então vire à direita em %1</translation>
    </message>
    <message>
        <source> and make a slight right</source>
        <translation> e então vire levemente à direita</translation>
    </message>
    <message>
        <source> and make a slight right onto %1</source>
        <translation> e então vire levemente à direita em %1</translation>
    </message>
    <message>
        <source> and make a U-turn</source>
        <translation> e então faça retorno</translation>
    </message>
    <message>
        <source> and make a U-turn onto %1</source>
        <translation> e então faça retorno em %1</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoMap</name>
    <message>
        <source>No Map</source>
        <translation>Sem mapa</translation>
    </message>
    <message>
        <source>Plugin does not support mapping.</source>
        <translation>O plugin não suporta mapeamento.</translation>
    </message>
</context>
<context>
    <name>GeoServiceProviderFactoryEsri</name>
    <message>
        <source>Esri plugin requires a &apos;esri.token&apos; parameter.
Please visit https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</source>
        <translation>O plugin Esri requer um parâmetro &apos;esri.token&apos;.
Visite https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</translation>
    </message>
</context>
<context>
    <name>PlaceSearchReplyEsri</name>
    <message>
        <source>Response parse error</source>
        <translation>Erro de análise de resposta</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineItemsOverlay</name>
    <message>
        <source>Empty Map</source>
        <translation>Mapa vazio</translation>
    </message>
</context>
<context>
    <name>QGeoCodeReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Erro de análise de resposta</translation>
    </message>
</context>
<context>
    <name>QGeoServiceProviderFactoryMapbox</name>
    <message>
        <source>Mapbox plugin requires a &apos;mapbox.access_token&apos; parameter.
Please visit https://www.mapbox.com</source>
        <translation>O plugin Mapbox requer um parâmetro &apos;mapbox.access_token&apos;.
Visite https://www.mapbox.com</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineMapbox</name>
    <message>
        <source>Street</source>
        <extracomment>Noun describing map type &apos;Street map&apos;</extracomment>
        <translation>Rua</translation>
    </message>
    <message>
        <source>Light</source>
        <extracomment>Noun describing type of a map using light colors (weak contrast)</extracomment>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Dark</source>
        <extracomment>Noun describing type of a map using dark colors</extracomment>
        <translation>Escuro</translation>
    </message>
    <message>
        <source>Satellite</source>
        <extracomment>Noun describing type of a map created by satellite</extracomment>
        <translation>Satélite</translation>
    </message>
    <message>
        <source>Streets Satellite</source>
        <extracomment>Noun describing type of a street map created by satellite</extracomment>
        <translation>Satélite ruas</translation>
    </message>
    <message>
        <source>Wheatpaste</source>
        <extracomment>Noun describing type of a map using wheat paste colors</extracomment>
        <translation>Cores pasteis</translation>
    </message>
    <message>
        <source>Streets Basic</source>
        <extracomment>Noun describing type of a basic street map</extracomment>
        <translation>Ruas básico</translation>
    </message>
    <message>
        <source>Comic</source>
        <extracomment>Noun describing type of a map using cartoon-style fonts</extracomment>
        <translation>Cômico</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <extracomment>Noun describing type of a map for outdoor activities</extracomment>
        <translation>Ar livre</translation>
    </message>
    <message>
        <source>Run Bike Hike</source>
        <extracomment>Noun describing type of a map for sports</extracomment>
        <translation>Bicicleta e caminhada</translation>
    </message>
    <message>
        <source>Pencil</source>
        <extracomment>Noun describing type of a map drawn by pencil</extracomment>
        <translation>Caneta</translation>
    </message>
    <message>
        <source>Pirates</source>
        <extracomment>Noun describing type of a treasure map with pirate boat watermark</extracomment>
        <translation>Piratas</translation>
    </message>
    <message>
        <source>Emerald</source>
        <extracomment>Noun describing type of a map using emerald colors</extracomment>
        <translation>Esmeralda</translation>
    </message>
    <message>
        <source>High Contrast</source>
        <extracomment>Noun describing type of a map with high contrast</extracomment>
        <translation>Alto contraste</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Erro de análise de resposta</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchSuggestionReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Erro de análise de resposta</translation>
    </message>
</context>
<context>
    <name>QGeoMapMapboxGL</name>
    <message>
        <source>Development access token, do not use in production.</source>
        <translation>Token de acesso de desenvolvimento, não use em produção.</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineMapboxGL</name>
    <message>
        <source>China Streets</source>
        <translation>Ruas da China</translation>
    </message>
    <message>
        <source>China Light</source>
        <translation>China claro</translation>
    </message>
    <message>
        <source>China Dark</source>
        <translation>China escuro</translation>
    </message>
    <message>
        <source>Streets</source>
        <translation>Ruas</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>Bright</source>
        <translation>Brilhante</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <translation>Ar livre</translation>
    </message>
    <message>
        <source>Satellite</source>
        <translation>Satélite</translation>
    </message>
    <message>
        <source>Satellite Streets</source>
        <translation>Satélite ruas</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <source>Navigation Preview Day</source>
        <translation>Visualização diurna da navegação</translation>
    </message>
    <message>
        <source>Navigation Preview Night</source>
        <translation>Visualização noturna da navegação</translation>
    </message>
    <message>
        <source>Navigation Guidance Day</source>
        <translation>Orientação diurna da navegação</translation>
    </message>
    <message>
        <source>Navigation Guidance Night</source>
        <translation>Orientação noturna da navegação</translation>
    </message>
    <message>
        <source>User provided style</source>
        <translation>Estilo fornecido pelo usuário</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineNokia</name>
    <message>
        <source>Street Map</source>
        <translation>Mapa de ruas</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode</source>
        <translation>Vista normal do mapa em modo diurno</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Mapa de satélite</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Vista de satélite do mapa em modo diurno</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Mapa de terreno</translation>
    </message>
    <message>
        <source>Terrain map view in daylight mode</source>
        <translation>Vista de terreno do mapa em modo diurno</translation>
    </message>
    <message>
        <source>Hybrid Map</source>
        <translation>Mapa híbrido</translation>
    </message>
    <message>
        <source>Satellite map view with streets in daylight mode</source>
        <translation>Vista de satélite do mapa com ruas em modo diurno</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Mapa de trânsito</translation>
    </message>
    <message>
        <source>Color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Vista de cores reduzida do mapa com transporte público em modo diurno</translation>
    </message>
    <message>
        <source>Gray Street Map</source>
        <translation>Mapa de ruas cinza</translation>
    </message>
    <message>
        <source>Color-reduced map view in daylight mode</source>
        <translation>Vista de cores reduzida do mapa em modo diurno</translation>
    </message>
    <message>
        <source>Mobile Street Map</source>
        <translation>Mapa de ruas móvel</translation>
    </message>
    <message>
        <source>Mobile normal map view in daylight mode</source>
        <translation>Vista normal do mapa móvel em modo diurno</translation>
    </message>
    <message>
        <source>Mobile Terrain Map</source>
        <translation>Mapa de terreno móvel</translation>
    </message>
    <message>
        <source>Mobile terrain map view in daylight mode</source>
        <translation>Vista de terreno do mapa móvel em modo diurno</translation>
    </message>
    <message>
        <source>Mobile Hybrid Map</source>
        <translation>Mapa híbrido móvel</translation>
    </message>
    <message>
        <source>Mobile satellite map view with streets in daylight mode</source>
        <translation>Vista de satélite do mapa móvel com ruas em modo diurno</translation>
    </message>
    <message>
        <source>Mobile Transit Map</source>
        <translation>Mapa de trânsito móvel</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Vista de cores reduzida do mapa móvel com transporte público em modo diurno</translation>
    </message>
    <message>
        <source>Mobile Gray Street Map</source>
        <translation>Mapa de ruas móvel cinza</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in daylight mode</source>
        <translation>Vista de cores reduzida do mapa móvel em modo diurno</translation>
    </message>
    <message>
        <source>Custom Street Map</source>
        <translation>Mapa de ruas personalizado</translation>
    </message>
    <message>
        <source>Night Street Map</source>
        <translation>Mapa de ruas noturno</translation>
    </message>
    <message>
        <source>Normal map view in night mode</source>
        <translation>Vista normal do mapa em modo noturno</translation>
    </message>
    <message>
        <source>Mobile Night Street Map</source>
        <translation>Mapa de ruas móvel noturno</translation>
    </message>
    <message>
        <source>Mobile normal map view in night mode</source>
        <translation>Vista normal do mapa móvel em modo noturno</translation>
    </message>
    <message>
        <source>Gray Night Street Map</source>
        <translation>Mapa de ruas noturno cinza</translation>
    </message>
    <message>
        <source>Color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Vista de cores reduzida do mapa modo noturno (usado especialmente para mapas de fundo)</translation>
    </message>
    <message>
        <source>Mobile Gray Night Street Map</source>
        <translation>Mapa de ruas noturno móvel cinza</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Vista de cores reduzida do mapa móvel em modo noturno (usado especialmente para mapas de fundo)</translation>
    </message>
    <message>
        <source>Pedestrian Street Map</source>
        <translation>Mapa de ruas pedestre</translation>
    </message>
    <message>
        <source>Pedestrian map view in daylight mode</source>
        <translation>Vista do mapa pedestre em modo diurno</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Street Map</source>
        <translation>Mapa de ruas móvel pedestre</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in daylight mode for mobile usage</source>
        <translation>Vista do mapa móvel pedestre em modo diurno para uso móvel</translation>
    </message>
    <message>
        <source>Pedestrian Night Street Map</source>
        <translation>Mapa de ruas pedestre noturno</translation>
    </message>
    <message>
        <source>Pedestrian map view in night mode</source>
        <translation>Vista do mapa pedestre em modo noturno</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Night Street Map</source>
        <translation>Mapa de ruas móvel pedestre noturno</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in night mode for mobile usage</source>
        <translation>Vista do mapa móvel pedestre em modo noturno para uso móvel</translation>
    </message>
    <message>
        <source>Car Navigation Map</source>
        <translation>Mapa de navegação em automóveis</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode for car navigation</source>
        <translation>Vista do mapa em modo diurno para navegação em automóveis</translation>
    </message>
</context>
<context>
    <name>QGeoTileFetcherNokia</name>
    <message>
        <source>Mapping manager no longer exists</source>
        <translation>O gerenciamento de mapas não existe mais</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV4</name>
    <message>
        <source>Go straight.</source>
        <translation>Siga em frente.</translation>
    </message>
    <message>
        <source>Go straight onto %1.</source>
        <translation>Siga em frente em %1.</translation>
    </message>
    <message>
        <source>Turn slightly right.</source>
        <translation>Vire ligeiramente à direita.</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1.</source>
        <translation>Vire ligeiramente à direita em %1.</translation>
    </message>
    <message>
        <source>Turn right.</source>
        <translation>Vire à direita.</translation>
    </message>
    <message>
        <source>Turn right onto %1.</source>
        <translation>Vire à direita em %1.</translation>
    </message>
    <message>
        <source>Make a sharp right.</source>
        <translation>Faça uma curva acentuada à direita.</translation>
    </message>
    <message>
        <source>Make a sharp right onto %1.</source>
        <translation>Faça uma curva acentuada à direita em %1.</translation>
    </message>
    <message>
        <source>When it is safe to do so, perform a U-turn.</source>
        <translation>Quando for seguro, faça retorno.</translation>
    </message>
    <message>
        <source>Make a sharp left.</source>
        <translation>Faça uma curva acentuada à esquerda.</translation>
    </message>
    <message>
        <source>Make a sharp left onto %1.</source>
        <translation>Faça uma curva acentuada à esquerda em %1.</translation>
    </message>
    <message>
        <source>Turn left.</source>
        <translation>Vire à esquerda.</translation>
    </message>
    <message>
        <source>Turn left onto %1.</source>
        <translation>Vire à esquerda em %1.</translation>
    </message>
    <message>
        <source>Turn slightly left.</source>
        <translation>Vire ligeiramente à esquerda.</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1.</source>
        <translation>Vire ligeiramente à esquerda em %1.</translation>
    </message>
    <message>
        <source>Reached waypoint.</source>
        <translation>Chegou no destino.</translation>
    </message>
    <message>
        <source>Head on.</source>
        <translation>Siga em frente.</translation>
    </message>
    <message>
        <source>Head onto %1.</source>
        <translation>Siga em frente em %1.</translation>
    </message>
    <message>
        <source>Enter the roundabout.</source>
        <translation>Entre na rotatória.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit.</source>
        <translation>Na rotatória pegue a primeira saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit onto %1.</source>
        <translation>Na rotatória pegue a primeira saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit.</source>
        <translation>Na rotatória pegue a segunda saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit onto %1.</source>
        <translation>Na rotatória pegue a segunda saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit.</source>
        <translation>Na rotatória pegue a terceira saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit onto %1.</source>
        <translation>Na rotatória pegue a terceira saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit.</source>
        <translation>Na rotatória pegue a quarta saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit onto %1.</source>
        <translation>Na rotatória pegue a quarta saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit.</source>
        <translation>Na rotatória pegue a quinta saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit onto %1.</source>
        <translation>Na rotatória pegue a quinta saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit.</source>
        <translation>Na rotatória pegue a sexta saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit onto %1.</source>
        <translation>Na rotatória pegue a sexta saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit.</source>
        <translation>Na rotatória pegue a sétima saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit onto %1.</source>
        <translation>Na rotatória pegue a sétima saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit.</source>
        <translation>Na rotatória pegue a oitava saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit onto %1.</source>
        <translation>Na rotatória pegue a oitava saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit.</source>
        <translation>Na rotatória pegue a nona saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit onto %1.</source>
        <translation>Na rotatória pegue a nona saída em %1.</translation>
    </message>
    <message>
        <source>Leave the roundabout.</source>
        <translation>Saia da rotatória.</translation>
    </message>
    <message>
        <source>Leave the roundabout onto %1.</source>
        <translation>Saia da rotatória em %1.</translation>
    </message>
    <message>
        <source>Stay on the roundabout.</source>
        <translation>Permaneça na rotatória.</translation>
    </message>
    <message>
        <source>Start at the end of the street.</source>
        <translation>Comece no final da rua.</translation>
    </message>
    <message>
        <source>Start at the end of %1.</source>
        <translation>Comece no final da rua em %1.</translation>
    </message>
    <message>
        <source>You have reached your destination.</source>
        <translation>Você chegou ao seu destino.</translation>
    </message>
    <message>
        <source>Don&apos;t know what to say for &apos;%1&apos;</source>
        <translation>Não sei o que dizer para &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineOsm</name>
    <message>
        <source>Street Map</source>
        <translation>Mapa de ruas</translation>
    </message>
    <message>
        <source>Street map view in daylight mode</source>
        <translation>Vista do mapa de ruas em modo diurno</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Mapa de satélite</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Vista do mapa de satélite em modo diurno</translation>
    </message>
    <message>
        <source>Cycle Map</source>
        <translation>Mapa ciclístico</translation>
    </message>
    <message>
        <source>Cycle map view in daylight mode</source>
        <translation>Vista do mapa ciclístico em modo diurno</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Mapa de trânsito</translation>
    </message>
    <message>
        <source>Public transit map view in daylight mode</source>
        <translation>Vista do mapa de trânsito público em modo diurno</translation>
    </message>
    <message>
        <source>Night Transit Map</source>
        <translation>Mapa de trânsito noturno</translation>
    </message>
    <message>
        <source>Public transit map view in night mode</source>
        <translation>Vista do mapa de trânsito público em modo noturno</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Mapa de terreno</translation>
    </message>
    <message>
        <source>Terrain map view</source>
        <translation>Vista do mapa de terreno</translation>
    </message>
    <message>
        <source>Hiking Map</source>
        <translation>Mapa de caminhada</translation>
    </message>
    <message>
        <source>Hiking map view</source>
        <translation>Vista do mapa de caminhada</translation>
    </message>
    <message>
        <source>Custom URL Map</source>
        <translation>Mapa de URL personalizado</translation>
    </message>
    <message>
        <source>Custom url map view set via urlprefix parameter</source>
        <translation>Vista do mapa de URL personalizado definido pelo parâmetro urlprefix</translation>
    </message>
    <message>
        <source>OpenStreetMap street map</source>
        <translation>Mapa de ruas do OpenStreetMap</translation>
    </message>
    <message>
        <source>OpenStreetMap satellite map</source>
        <translation>Mapa de satélite do OpenStreetMap</translation>
    </message>
</context>
<context>
    <name>QPlaceManagerEngineOsm</name>
    <message>
        <source>Aeroway</source>
        <translation>Aeroporto</translation>
    </message>
    <message>
        <source>Amenity</source>
        <translation>Estabelecimento</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Edifício</translation>
    </message>
    <message>
        <source>Highway</source>
        <translation>Rodovia</translation>
    </message>
    <message>
        <source>Historic</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <source>Land use</source>
        <translation>Uso do solo</translation>
    </message>
    <message>
        <source>Leisure</source>
        <translation>Lazer</translation>
    </message>
    <message>
        <source>Man made</source>
        <translation>Feito pelo home</translation>
    </message>
    <message>
        <source>Natural</source>
        <translation>Natural</translation>
    </message>
    <message>
        <source>Place</source>
        <translation>Local</translation>
    </message>
    <message>
        <source>Railway</source>
        <translation>Ferrovia</translation>
    </message>
    <message>
        <source>Shop</source>
        <translation>Loja</translation>
    </message>
    <message>
        <source>Tourism</source>
        <translation>Turismo</translation>
    </message>
    <message>
        <source>Waterway</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Network request error</source>
        <translation>Erro de requisição de rede</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyOsm</name>
    <message>
        <source>Response parse error</source>
        <translation>Erro de análise de resposta</translation>
    </message>
</context>
<context>
    <name>QDeclarativeNavigator</name>
    <message>
        <source>Plugin does not support navigation.</source>
        <translation>O plugin não suporta navegação.</translation>
    </message>
    <message>
        <source>Failed to create a navigator object.</source>
        <translation>Falha ao criar um objeto navegador.</translation>
    </message>
</context>
<context>
    <name>QGeoRouteReplyOsm</name>
    <message>
        <source>Go straight.</source>
        <translation>Siga em frente.</translation>
    </message>
    <message>
        <source>Go straight onto %1.</source>
        <translation>Siga em frente até %1.</translation>
    </message>
    <message>
        <source>Turn slightly right.</source>
        <translation>Vire ligeiramente à direita.</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1.</source>
        <translation>Vire ligeiramente à direita em %1.</translation>
    </message>
    <message>
        <source>Turn right.</source>
        <translation>Vire à direita.</translation>
    </message>
    <message>
        <source>Turn right onto %1.</source>
        <translation>Vire à direita em %1.</translation>
    </message>
    <message>
        <source>Make a sharp right.</source>
        <translation>Faça uma curva acentuada à direita.</translation>
    </message>
    <message>
        <source>Make a sharp right onto %1.</source>
        <translation>Faça uma curva acentuada à direita em %1.</translation>
    </message>
    <message>
        <source>When it is safe to do so, perform a U-turn.</source>
        <translation>Quando for seguro, faça retorno.</translation>
    </message>
    <message>
        <source>Make a sharp left.</source>
        <translation>Faça uma curva acentuada à esquerda.</translation>
    </message>
    <message>
        <source>Make a sharp left onto %1.</source>
        <translation>Faça uma curva acentuada à esquerda em %1.</translation>
    </message>
    <message>
        <source>Turn left.</source>
        <translation>Vire à esquerda.</translation>
    </message>
    <message>
        <source>Turn left onto %1.</source>
        <translation>Vire à esquerda em %1.</translation>
    </message>
    <message>
        <source>Turn slightly left.</source>
        <translation>Vire ligeiramente à esquerda.</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1.</source>
        <translation>Vire ligeiramente à esquerda em %1.</translation>
    </message>
    <message>
        <source>Reached waypoint.</source>
        <translation>Chegou no destino.</translation>
    </message>
    <message>
        <source>Head on.</source>
        <translation>Siga em frente.</translation>
    </message>
    <message>
        <source>Head onto %1.</source>
        <translation>Siga em frente em %1.</translation>
    </message>
    <message>
        <source>Enter the roundabout.</source>
        <translation>Entre na rotatória.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit.</source>
        <translation>Na rotatória pegue a primeira saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit onto %1.</source>
        <translation>Na rotatória pegue a primeira saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit.</source>
        <translation>Na rotatória pegue a segunda saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit onto %1.</source>
        <translation>Na rotatória pegue a segunda saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit.</source>
        <translation>Na rotatória pegue a terceira saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit onto %1.</source>
        <translation>Na rotatória pegue a terceira saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit.</source>
        <translation>Na rotatória pegue a quarta saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit onto %1.</source>
        <translation>Na rotatória pegue a quarta saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit.</source>
        <translation>Na rotatória pegue a quinta saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit onto %1.</source>
        <translation>Na rotatória pegue a quinta saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit.</source>
        <translation>Na rotatória pegue a sexta saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit onto %1.</source>
        <translation>Na rotatória pegue a sexta saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit.</source>
        <translation>Na rotatória pegue a sétima saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit onto %1.</source>
        <translation>Na rotatória pegue a sétima saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit.</source>
        <translation>Na rotatória pegue a oitava saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit onto %1.</source>
        <translation>Na rotatória pegue a oitava saída em %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit.</source>
        <translation>Na rotatória pegue a nona saída.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit onto %1.</source>
        <translation>Na rotatória pegue a nona saída em %1.</translation>
    </message>
    <message>
        <source>Leave the roundabout.</source>
        <translation>Saia da rotatória.</translation>
    </message>
    <message>
        <source>Leave the roundabout onto %1.</source>
        <translation>Saia da rotatória em %1.</translation>
    </message>
    <message>
        <source>Stay on the roundabout.</source>
        <translation>Permaneça na rotatória.</translation>
    </message>
    <message>
        <source>Start at the end of the street.</source>
        <translation>Comece no final da rua.</translation>
    </message>
    <message>
        <source>Start at the end of %1.</source>
        <translation>Comece no final da rua em %1.</translation>
    </message>
    <message>
        <source>You have reached your destination.</source>
        <translation>Você chegou ao seu destino.</translation>
    </message>
    <message>
        <source>Don&apos;t know what to say for &apos;%1&apos;</source>
        <translation>Não sei o que dizer para &apos;%1&apos;</translation>
    </message>
</context>
</TS>
